package prova.mapexample;

import android.content.Intent;
import android.location.Address;
import android.location.Geocoder;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import java.io.IOException;
import java.util.List;


public class MainActivity extends ActionBarActivity implements LocationListener  {

    private TextView latitude;
    private TextView longitude;
    private TextView countryName;

    private LocationManager locationManager;

    private static final long MINTIME=10;
    private static final float MINDISTANCE=100;

    public static final double LATLNG_NOT_AVAILABLE=1000;

    private double currentLatitude;
    private double currentLongitude;

    private Geocoder geocoder;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        latitude=(TextView) findViewById(R.id.latitude);
        longitude=(TextView) findViewById(R.id.longitude);
        countryName=(TextView) findViewById(R.id.countryName);

        currentLatitude=LATLNG_NOT_AVAILABLE;
        currentLongitude=LATLNG_NOT_AVAILABLE;
        geocoder=new Geocoder(this);

        // Get instance of LocationManager system service
        locationManager=(LocationManager) getSystemService(LOCATION_SERVICE);
        locationManager.requestLocationUpdates(LocationManager.GPS_PROVIDER,MINTIME,MINDISTANCE,this);

    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }


    public void showWebViewSimple(View view) {
        Intent intent;
        switch (view.getId()) {

            case R.id.buttonWebView1:
                intent=new Intent(this,SecondActivity.class);
                intent.putExtra("WEB_ADDRESS","http://www.cs.unibo.it");
                startActivity(intent);
                break;
            case R.id.buttonWebView2:
                intent=new Intent(this,SecondActivity.class);
                intent.putExtra("WEB_ADDRESS","https://www.google.it/maps/place/Mura+Anteo+Zamboni,+7/@44.4971018,11.3559908,17z/data=!4m3!3m2!1s0x477fd4ba9cbbe159:0xa8ab8911c0d58fd3!4b1");
                startActivity(intent);
                break;
            case R.id.buttonGoogleMap:
                intent=new Intent(this,MapExampleActivity.class);
                intent.putExtra("LATITUDE",currentLatitude);
                intent.putExtra("LONGITUDE",currentLongitude);
                startActivity(intent);
                break;

        }


    }

    @Override
    public void onLocationChanged(Location location) {

        Toast t= Toast.makeText(this,"New GPS Sample Available", Toast.LENGTH_SHORT);
        t.show();

        latitude.setText(location.getLatitude()+"");
        longitude.setText(location.getLongitude()+"");

        currentLatitude=location.getLatitude();
        currentLongitude=location.getLongitude();


        try {
            List<Address> addressList = geocoder.getFromLocation(currentLatitude, currentLongitude, 1);
            if ((addressList!=null) && (addressList.size()>0)) {
                Address currentAddress=addressList.get(0);
                countryName.setText(currentAddress.getCountryName());
            }
        }
        catch(IOException ex) {

        }

    }

    @Override
    public void onStatusChanged(String provider, int status, Bundle extras) {

    }

    @Override
    public void onProviderEnabled(String provider) {

    }

    @Override
    public void onProviderDisabled(String provider) {

    }
}
