package prova.mapexample;

import android.content.Intent;
import android.graphics.Color;
import android.support.v4.app.FragmentActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.RadioGroup;
import android.widget.Toast;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.CameraPosition;
import com.google.android.gms.maps.model.CircleOptions;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;
import com.google.android.gms.maps.model.PolygonOptions;
import com.google.android.gms.maps.model.PolylineOptions;
import com.google.android.gms.maps.model.TileOverlayOptions;


import org.json.JSONException;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;
import java.util.Scanner;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;


public class MapExampleActivity extends FragmentActivity implements RadioGroup.OnCheckedChangeListener {

    private GoogleMap mMap; // Might be null if Google Play services APK is not available.
    private RadioGroup selectMode;
    private int currentBearing=0;
    private int currentTilt=0;
    private Random randomGenerator;
    private LatLng currentTarget;

    private LatLng BOLOGNA_POINT=new LatLng(44.494287,11.341904);

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_map_example);
        setUpMapIfNeeded();

        Intent intent=getIntent();

        double latitudeMarker=intent.getExtras().getDouble("LATITUDE");
        double longitudeMarker=intent.getExtras().getDouble("LONGITUDE");

        if ((latitudeMarker!=MainActivity.LATLNG_NOT_AVAILABLE) && (longitudeMarker!=MainActivity.LATLNG_NOT_AVAILABLE)) {
            currentTarget=new LatLng(latitudeMarker,longitudeMarker);
            createMarker(currentTarget);
        }

        selectMode=(RadioGroup) findViewById(R.id.selectMode);
        selectMode.setOnCheckedChangeListener(this);
        randomGenerator=new Random();
        currentTarget=BOLOGNA_POINT;
        changeCameraSetting();
    }






    @Override
    protected void onResume() {
        super.onResume();
        setUpMapIfNeeded();
    }

    /**
     * Sets up the map if it is possible to do so (i.e., the Google Play services APK is correctly
     * installed) and the map has not already been instantiated.. This will ensure that we only ever
     * call {@link #setUpMap()} once when {@link #mMap} is not null.
     * <p/>
     * If it isn't installed {@link SupportMapFragment} (and
     * {@link com.google.android.gms.maps.MapView MapView}) will show a prompt for the user to
     * install/update the Google Play services APK on their device.
     * <p/>
     * A user can return to this FragmentActivity after following the prompt and correctly
     * installing/updating/enabling the Google Play services. Since the FragmentActivity may not
     * have been completely destroyed during this process (it is likely that it would only be
     * stopped or paused), {@link #onCreate(Bundle)} may not be called again so we should call this
     * method in {@link #onResume()} to guarantee that it will be called.
     */
    private void setUpMapIfNeeded() {
        // Do a null check to confirm that we have not already instantiated the map.
        if (mMap == null) {
            // Try to obtain the map from the SupportMapFragment.
            mMap = ((SupportMapFragment) getSupportFragmentManager().findFragmentById(R.id.map))
                    .getMap();
            // Check if we were successful in obtaining the map.
           // if (mMap != null) {
           //     setUpMap();
           // }
        }
    }

    /**
     * This is where we can add markers or lines, add listeners or move the camera. In this case, we
     * just add a marker near Africa.
     * <p/>
     * This should only be called once and when we are sure that {@link #mMap} is not null.
     */
    private void setUpMap() {
        //mMap.addMarker(new MarkerOptions().position(new LatLng(0, 0)).title("Marker"));
    }

    @Override
    public void onCheckedChanged(RadioGroup group, int checkedId) {
        switch(checkedId) {
            case R.id.mode1:
                mMap.setMapType(GoogleMap.MAP_TYPE_HYBRID);
                break;
            case R.id.mode2:
                mMap.setMapType(GoogleMap.MAP_TYPE_SATELLITE);
                break;
            case R.id.mode3:
                mMap.setMapType(GoogleMap.MAP_TYPE_TERRAIN);
                break;
        }
    }

    public void mapCustomize(View view) {
        switch(view.getId()) {
            case R.id.tiltDown:
                if (currentTilt>=10)
                    currentTilt-=10;
                break;
            case R.id.tiltUp:
                currentTilt+=10;
                break;
            case R.id.bearDown:
                if (currentBearing>=10)
                  currentBearing-=10;
                break;
            case R.id.bearUp:
                currentBearing+=10;
                break;
            case R.id.circleButton:
                createCircle();
                break;
            case R.id.polylineButton:
                createPolyLine();
                break;
            case R.id.polygonButton:
                createPolygon();
                break;
            case R.id.markerButton:
                createMarker();
                break;
        }

        changeCameraSetting();
    }


    private void createMarker() {
        currentTarget=new LatLng(randomValue(90), randomValue(180));
        createMarker(currentTarget);

    }

    private void createMarker(LatLng currentTarget) {

        mMap.addMarker(new MarkerOptions()
                .position(currentTarget)
                .title("New Maker")
                .snippet("Latitude " + currentTarget.latitude + " Longitude " + currentTarget.longitude)
                .icon(BitmapDescriptorFactory.fromResource(R.drawable.mymarkericon)));
    }


    private void createCircle() {

        currentTarget=new LatLng(randomValue(90), randomValue(180));
        CircleOptions circleOptions = new CircleOptions()
                .center(currentTarget)
                .fillColor(Color.RED)
                .strokeColor(Color.RED)
                .radius(50000);

        mMap.addCircle(circleOptions);

    }


    private void createPolyLine() {
        currentTarget=new LatLng(randomValue(90), randomValue(180));
        PolylineOptions rectOptions = new PolylineOptions()
                .add(currentTarget)
                .add(new LatLng(randomValue(90), randomValue(180)))
                .add(new LatLng(randomValue(90), randomValue(180)))
                .add(new LatLng(randomValue(90), randomValue(180)));

        mMap.addPolyline(rectOptions);
    }


    private void createPolygon() {
        currentTarget=new LatLng(randomValue(90), randomValue(180));

        PolygonOptions rectOptions = new PolygonOptions()
                .add(currentTarget)
                .add(new LatLng(randomValue(90), randomValue(180)))
                .add(new LatLng(randomValue(90), randomValue(180)))
                .add(new LatLng(randomValue(90), randomValue(180)))
                .strokeColor(Color.RED);

        mMap.addPolygon(rectOptions);
    }



    private double randomValue(double maxValue) {
        double value=randomGenerator.nextDouble()*maxValue;
        if (randomGenerator.nextDouble() <0.5)
            return -value;
        else
            return value;
    }




    private void changeCameraSetting() {
        CameraPosition cameraPosition = new CameraPosition.Builder()
                .target(currentTarget)
                .bearing(currentBearing)                // Sets the orientation of the camera to east
                .tilt(currentTilt)                   // Sets the tilt of the camera to 30 degrees
                .build();                   // Creates a CameraPosition from the builder
        mMap.animateCamera(CameraUpdateFactory.newCameraPosition(cameraPosition));
    }



}
