package it.unibo.lbedogni.maps;

import android.app.AlertDialog;
import android.location.Address;
import android.location.Geocoder;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

public class MapsA extends FragmentActivity implements OnMapReadyCallback, View.OnClickListener, GoogleMap.OnMapClickListener, GoogleMap.OnMarkerClickListener, GoogleMap.OnMapLongClickListener {

    private GoogleMap mMap;
    double thisLat;
    double thisLon;

    Button latminus;
    Button latplus;
    Button lonminus;
    Button lonplus;

    EditText etTitle;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager()
                .findFragmentById(R.id.map);
        mapFragment.getMapAsync(this);

        etTitle = (EditText) findViewById(R.id.markerTitle);

        latminus = (Button) findViewById(R.id.latminus);
        latplus = (Button) findViewById(R.id.latplus);
        lonminus = (Button) findViewById(R.id.lonminus);
        lonplus = (Button) findViewById(R.id.lonplus);

        latminus.setOnClickListener(this);
        latplus.setOnClickListener(this);
        lonminus.setOnClickListener(this);
        lonplus.setOnClickListener(this);

    }


    @Override
    public void onMapReady(GoogleMap googleMap) {
        mMap = googleMap;
        mMap.setOnMapClickListener(this);
        mMap.setOnMarkerClickListener(this);
        mMap.setOnMapLongClickListener(this);

        mMap.setMyLocationEnabled(true);

        mMap.setTrafficEnabled(true);
        thisLat = 44.497585;
        thisLon = 11.356129;

        // Add a marker in Sydney and move the camera
        LatLng bologna = new LatLng(thisLat, thisLon);
        mMap.addMarker(new MarkerOptions().position(bologna).title("Bologna, Italy"));
        mMap.moveCamera(CameraUpdateFactory.newLatLng(bologna));

        mMap.animateCamera(CameraUpdateFactory.zoomTo(15));
    }

    @Override
    public void onClick(View v) {
        if (v == latminus) {
            thisLat -= 0.0001;
        } else if (v == latplus) {
            thisLat += 0.0001;
        } else if (v == lonminus) {
            thisLon -= 0.0001;
        } else {
            thisLon += 0.0001;
        }
        mMap.moveCamera(CameraUpdateFactory.newLatLng(new LatLng(thisLat,thisLon)));
    }

    @Override
    public void onMapClick(LatLng latLng) {
        mMap.addMarker(new MarkerOptions().position(latLng).title(etTitle.getText().toString()));
    }

    @Override
    public void onMapLongClick(LatLng latLng) {
        mMap.setTrafficEnabled(!mMap.isTrafficEnabled());
    }

    @Override
    public boolean onMarkerClick(Marker marker) {
        Geocoder geocoder;
        List<Address> addresses = new ArrayList<Address>();
        geocoder = new Geocoder(this, Locale.getDefault());

        try {
            addresses = geocoder.getFromLocation(marker.getPosition().latitude, marker.getPosition().longitude, 1); // Here 1 represent max location result to returned, by documents it recommended 1 to 5
        } catch (IOException e) {}

        if (addresses.size() > 0) {
            String address = addresses.get(0).getAddressLine(0); // If any additional address line present than only, check with max available address lines by getMaxAddressLineIndex()
            String city = addresses.get(0).getLocality();
            String country = addresses.get(0).getCountryName();
            String postalCode = addresses.get(0).getPostalCode();

            AlertDialog.Builder adBuilder = new AlertDialog.Builder(this);
            adBuilder.setTitle(address);
            adBuilder.setMessage(city + "," + country + "," + postalCode);
            AlertDialog ad = adBuilder.create();
            ad.show();
        } else {
            AlertDialog.Builder adBuilder = new AlertDialog.Builder(this);
            adBuilder.setTitle("No address");
            AlertDialog ad = adBuilder.create();
            ad.show();
        }
        return true;
    }
}
